import { __name } from './chunk-AJJZUHB4.js';
import { createAmazonBedrock } from '@ai-sdk/amazon-bedrock';
import { createCohere } from '@ai-sdk/cohere';
import { createGoogleGenerativeAI } from '@ai-sdk/google';
import { createMistral } from '@ai-sdk/mistral';
import { createOpenAI } from '@ai-sdk/openai';
import { embed as embed$1, embedMany as embedMany$1 } from 'ai';
import { createVoyage } from 'voyage-ai-provider';
import 'dotenv/config';

function getEmbeddingModel(embedding) {
  let embeddingModel;
  const { provider, model, apiKey } = embedding;
  if (provider === "OPEN_AI") {
    const openai = createOpenAI({
      apiKey: apiKey || process.env.OPENAI_API_KEY
    });
    embeddingModel = openai.embedding(model);
  } else if (provider === "COHERE") {
    const cohere = createCohere({
      apiKey: apiKey || process.env.COHERE_API_KEY
    });
    embeddingModel = cohere.embedding(model);
  } else if (provider === "AMAZON") {
    const amazon = createAmazonBedrock({
      region: process.env.AWS_REGION || "",
      accessKeyId: process.env.AWS_ACCESS_KEY_ID || "",
      secretAccessKey: process.env.AWS_SECRET_ACCESS_KEY || "",
      sessionToken: process.env.AWS_SESSION_TOKEN || ""
    });
    embeddingModel = amazon.embedding(model);
  } else if (provider === "GOOGLE") {
    const google = createGoogleGenerativeAI({
      baseURL: "https://generativelanguage.googleapis.com/v1beta",
      apiKey: apiKey || process.env.GOOGLE_GENERATIVE_AI_API_KEY || ""
    });
    embeddingModel = google.textEmbeddingModel(model);
  } else if (provider === "MISTRAL") {
    const mistral = createMistral({
      baseURL: "https://api.mistral.ai/v1",
      apiKey: apiKey || process.env.MISTRAL_API_KEY || ""
    });
    embeddingModel = mistral.textEmbeddingModel(model);
  } else if (provider === "VOYAGE") {
    const voyage = createVoyage({
      baseURL: "https://api.voyageai.com/v1",
      apiKey: apiKey || process.env.VOYAGE_API_KEY || ""
    });
    embeddingModel = voyage.textEmbeddingModel(model);
  } else {
    throw new Error(`Invalid embedding model`);
  }
  return embeddingModel;
}
__name(getEmbeddingModel, "getEmbeddingModel");
async function embed(value, embedding) {
  const embeddingModel = await getEmbeddingModel(embedding);
  const { maxRetries } = embedding;
  return await embed$1({
    model: embeddingModel,
    value,
    maxRetries
  });
}
__name(embed, "embed");
async function embedMany(value, embedding) {
  const embeddingModel = await getEmbeddingModel(embedding);
  const { maxRetries } = embedding;
  return await embedMany$1({
    model: embeddingModel,
    values: value,
    maxRetries
  });
}
__name(embedMany, "embedMany");

export { embed, embedMany };
