import { __name } from './chunk-AJJZUHB4.js';
import { trace, context, SpanStatusCode, SpanKind } from '@opentelemetry/api';

function hasActiveTelemetry() {
  try {
    return !!trace.getTracer("default-tracer");
  } catch {
    return false;
  }
}
__name(hasActiveTelemetry, "hasActiveTelemetry");
function withSpan(options) {
  return function(_target, propertyKey, descriptor) {
    if (!descriptor || typeof descriptor === "number") return;
    const originalMethod = descriptor.value;
    const methodName = String(propertyKey);
    descriptor.value = function(...args) {
      if (options?.skipIfNoTelemetry && !hasActiveTelemetry()) {
        return originalMethod.apply(this, args);
      }
      const tracer = trace.getTracer("default-tracer");
      let spanName;
      let spanKind;
      if (typeof options === "string") {
        spanName = options;
      } else if (options) {
        spanName = options.spanName || methodName;
        spanKind = options.spanKind;
      } else {
        spanName = methodName;
      }
      const span = tracer.startSpan(spanName, {
        kind: spanKind
      });
      const ctx = trace.setSpan(context.active(), span);
      args.forEach((arg, index) => {
        try {
          span.setAttribute(`${spanName}.argument.${index}`, JSON.stringify(arg));
        } catch (e) {
          span.setAttribute(`${spanName}.argument.${index}`, "[Not Serializable]");
        }
      });
      let result;
      try {
        result = context.with(ctx, () => originalMethod.apply(this, args));
        if (result instanceof Promise) {
          return result.then((resolvedValue) => {
            try {
              span.setAttribute(`${spanName}.result`, JSON.stringify(resolvedValue));
            } catch (e) {
              span.setAttribute(`${spanName}.result`, "[Not Serializable]");
            }
            return resolvedValue;
          }).finally(() => span.end());
        }
        try {
          span.setAttribute(`${spanName}.result`, JSON.stringify(result));
        } catch (e) {
          span.setAttribute(`${spanName}.result`, "[Not Serializable]");
        }
        return result;
      } catch (error) {
        span.setStatus({
          code: SpanStatusCode.ERROR,
          message: error instanceof Error ? error.message : "Unknown error"
        });
        if (error instanceof Error) {
          span.recordException(error);
        }
        throw error;
      } finally {
        if (!(result instanceof Promise)) {
          span.end();
        }
      }
    };
    return descriptor;
  };
}
__name(withSpan, "withSpan");
function InstrumentClass(options) {
  return function(target) {
    const methods = Object.getOwnPropertyNames(target.prototype);
    methods.forEach((method) => {
      if (options?.excludeMethods?.includes(method) || method === "constructor") return;
      if (options?.methodFilter && !options.methodFilter(method)) return;
      const descriptor = Object.getOwnPropertyDescriptor(target.prototype, method);
      if (descriptor && typeof descriptor.value === "function") {
        Object.defineProperty(target.prototype, method, withSpan({
          spanName: options?.prefix ? `${options.prefix}.${method}` : method,
          skipIfNoTelemetry: true,
          spanKind: options?.spanKind || SpanKind.INTERNAL
        })(target, method, descriptor));
      }
    });
    return target;
  };
}
__name(InstrumentClass, "InstrumentClass");

export { InstrumentClass, hasActiveTelemetry, withSpan };
