import { hasActiveTelemetry } from './chunk-6ZVFVYLE.js';
import { __name, __publicField } from './chunk-AJJZUHB4.js';
import { trace, SpanStatusCode } from '@opentelemetry/api';
import { getNodeAutoInstrumentations } from '@opentelemetry/auto-instrumentations-node';
import { OTLPTraceExporter } from '@opentelemetry/exporter-trace-otlp-http';
import { Resource } from '@opentelemetry/resources';
import { NodeSDK } from '@opentelemetry/sdk-node';
import { ConsoleSpanExporter, AlwaysOnSampler, AlwaysOffSampler, TraceIdRatioBasedSampler, ParentBasedSampler } from '@opentelemetry/sdk-trace-base';
import { ATTR_SERVICE_NAME } from '@opentelemetry/semantic-conventions';

var sdkInstance = null;
var _Telemetry = class _Telemetry {
  constructor(config) {
    __publicField(this, "sdk", null);
    __publicField(this, "tracer", trace.getTracer("default"));
    __publicField(this, "name", "default-service");
    this.name = config.serviceName ?? "default-service";
    if (typeof window === "undefined") {
      if (process.env.NODE_ENV === "development" || !sdkInstance) {
        if (sdkInstance) {
          this.shutdown();
        }
        const exporter = config.export?.type === "otlp" ? new OTLPTraceExporter({
          url: config.export.endpoint,
          headers: config.export.headers
        }) : config.export?.type === "custom" ? config.export.exporter : new ConsoleSpanExporter();
        const sampler = this.getSampler(config);
        sdkInstance = new NodeSDK({
          resource: new Resource({
            [ATTR_SERVICE_NAME]: this.name
          }),
          traceExporter: exporter,
          sampler,
          instrumentations: [
            getNodeAutoInstrumentations()
          ]
        });
        try {
          sdkInstance.start();
          this.sdk = sdkInstance;
          _Telemetry.isInitialized = true;
        } catch (error) {
          console.warn("Failed to initialize OpenTelemetry:", error);
        }
      }
    }
    this.tracer = trace.getTracer(this.name);
  }
  getSampler(config) {
    if (!config.sampling) {
      return new AlwaysOnSampler();
    }
    if (!config.enabled) {
      return new AlwaysOffSampler();
    }
    switch (config.sampling.type) {
      case "ratio":
        return new TraceIdRatioBasedSampler(config.sampling.probability);
      case "always_on":
        return new AlwaysOnSampler();
      case "always_off":
        return new AlwaysOffSampler();
      case "parent_based":
        const rootSampler = new TraceIdRatioBasedSampler(config.sampling.root?.probability || 1);
        return new ParentBasedSampler({
          root: rootSampler
        });
      default:
        return new AlwaysOnSampler();
    }
  }
  async shutdown() {
    if (this.sdk && _Telemetry.isInitialized) {
      try {
        await this.sdk.shutdown();
        _Telemetry.isInitialized = false;
        global.__OTEL_SDK__ = void 0;
        global.__TELEMETRY__ = void 0;
      } catch (error) {
        console.warn("Error shutting down OpenTelemetry:", error);
      }
    }
  }
  /**
  * Initialize telemetry with the given configuration
  * @param config - Optional telemetry configuration object
  * @returns Telemetry instance that can be used for tracing
  */
  static init(config = {}) {
    try {
      if (!global.__TELEMETRY__) {
        global.__TELEMETRY__ = new _Telemetry(config);
      }
      return global.__TELEMETRY__;
    } catch (error) {
      console.error("Failed to initialize telemetry:", error);
      throw error;
    }
  }
  /**
  * Get the global telemetry instance
  * @throws {Error} If telemetry has not been initialized
  * @returns {Telemetry} The global telemetry instance
  */
  static get() {
    if (!global.__TELEMETRY__) {
      throw new Error("Telemetry not initialized");
    }
    return global.__TELEMETRY__;
  }
  /**
  * Wraps a class instance with telemetry tracing
  * @param instance The class instance to wrap
  * @param options Optional configuration for tracing
  * @returns Wrapped instance with all methods traced
  */
  traceClass(instance, options = {}) {
    const { skipIfNoTelemetry = true } = options;
    if (skipIfNoTelemetry && !hasActiveTelemetry()) {
      return instance;
    }
    const { spanNamePrefix = instance.constructor.name.toLowerCase(), attributes = {}, excludeMethods = [] } = options;
    return new Proxy(instance, {
      get: /* @__PURE__ */ __name((target, prop) => {
        const value = target[prop];
        if (typeof value === "function" && prop !== "constructor" && !prop.toString().startsWith("_") && !excludeMethods.includes(prop.toString())) {
          return this.traceMethod(value.bind(target), {
            spanName: `${spanNamePrefix}.${prop.toString()}`,
            attributes: {
              ...attributes,
              [`${spanNamePrefix}.name`]: target.constructor.name,
              [`${spanNamePrefix}.method.name`]: prop.toString()
            }
          });
        }
        return value;
      }, "get")
    });
  }
  /**
  * method to trace individual methods with proper context
  * @param method The method to trace
  * @param context Additional context for the trace
  * @returns Wrapped method with tracing
  */
  traceMethod(method, context) {
    const { skipIfNoTelemetry = true } = context;
    if (skipIfNoTelemetry && !hasActiveTelemetry()) {
      return method;
    }
    return async (...args) => {
      const span = this.tracer.startSpan(context.spanName);
      try {
        if (context.attributes) {
          span.setAttributes(context.attributes);
        }
        args.forEach((arg, index) => {
          try {
            span.setAttribute(`${context.spanName}.argument.${index}`, JSON.stringify(arg));
          } catch (e) {
            span.setAttribute(`${context.spanName}.argument.${index}`, "[Not Serializable]");
          }
        });
        const result = await method(...args);
        try {
          span.setAttribute(`${context.spanName}.result`, JSON.stringify(result));
        } catch (e) {
          span.setAttribute(`${context.spanName}.result`, "[Not Serializable]");
        }
        span.end();
        return result;
      } catch (error) {
        span.recordException(error);
        span.setStatus({
          code: SpanStatusCode.ERROR,
          message: error.message
        });
        span.end();
        throw error;
      }
    };
  }
};
__name(_Telemetry, "Telemetry");
__publicField(_Telemetry, "isInitialized", false);
var Telemetry = _Telemetry;

export { Telemetry };
