import { MastraBase } from './base.js';

interface BaseEntity {
    id: string;
    connectionId: string;
    name: string;
    createdAt: Date;
    updatedAt: Date | null;
    lastSyncId: string | null;
}
interface BaseRecord {
    id: string;
    entityId: string;
    data: Record<string, any>;
    createdAt: Date;
    updatedAt: Date | null;
    externalId: string;
    entityType: string;
}
declare enum PropertyType {
    'LONG_TEXT' = "LONG_TEXT",
    'SINGLE_LINE_TEXT' = "SINGLE_LINE_TEXT",
    'SINGLE_SELECT' = "SINGLE_SELECT",
    'MULTI_SELECT' = "MULTI_SELECT",
    'CHECKBOX' = "CHECKBOX",
    'DATE' = "DATE",
    'USER' = "USER",
    'BADGE_LIST' = "BADGE_LIST",
    'CURRENCY' = "CURRENCY",
    'URL' = "URL",
    'PHONE' = "PHONE",
    'CONTACT' = "CONTACT",
    'COMPANY' = "COMPANY",
    'PERSON' = "PERSON",
    'ENRICHMENT' = "ENRICHMENT",
    'COMPOSITE' = "COMPOSITE",
    'BOOLEAN' = "BOOLEAN",
    'NUMBER' = "NUMBER",
    'FLOAT' = "FLOAT",
    'JSON_OBJECT' = "JSON_OBJECT",
    'JSON_ARRAY' = "JSON_ARRAY"
}
declare enum FilterOperators {
    IS = "is",
    EQUAL = "eq",
    NOT_EQUAL = "not_eq",
    CONTAINS = "contains",
    IN = "in",
    NOT_IN = "not_in",
    GREATER_THAN = "gt",
    LESS_THAN = "lt",
    NOT_CONTAINS = "not_contains",
    GREATER_THAN_OR_EQUAL = "gte",
    LESS_THAN_OR_EQUAL = "lte",
    OP = "op",
    SET = "set",
    NOT_SET = "not_set"
}
interface FilterCondition {
    field: string;
    operator: FilterOperators;
    value: any;
}
interface SortOrder {
    field: string;
    direction: 'ASC' | 'DESC';
}
interface QueryOptions {
    filters?: FilterCondition[];
    sort?: SortOrder[];
    limit?: number;
    offset?: number;
}

interface DatabaseConfig {
    url: string;
}
declare abstract class MastraEngine extends MastraBase {
    /**
     * Initializes the database connection
     * @param config Configuration object for database connection
     */
    constructor(_config: DatabaseConfig);
    abstract createEntity(params: {
        name: string;
        connectionId: string;
    }): Promise<BaseEntity>;
    abstract getEntityById(params: {
        id: string;
    }): Promise<BaseEntity>;
    abstract getEntity({ connectionId, name }: {
        name?: string;
        connectionId?: string;
    }): Promise<BaseEntity | undefined>;
    abstract deleteEntityById({ id }: {
        id: string;
    }): Promise<BaseEntity>;
    abstract upsertRecords(params: {
        entityId: string;
        records: Pick<BaseRecord, 'externalId' | 'data' | 'entityType'>[];
    }): Promise<void>;
    abstract getRecordsByEntityId(params: {
        entityId: string;
    }): Promise<BaseRecord[]>;
    abstract getRecordsByEntityName({ name, connectionId, }: {
        name: string;
        connectionId: string;
    }): Promise<BaseRecord[]>;
    abstract getRecords({ entityName, connectionId, options, }: {
        entityName: string;
        options: QueryOptions;
        connectionId: string;
    }): Promise<BaseRecord[]>;
    abstract syncRecords({ connectionId, name, records, lastSyncId, }: {
        name: string;
        connectionId: string;
        records: Pick<BaseRecord, 'externalId' | 'data'>[];
        lastSyncId?: string;
    }): Promise<void>;
    abstract getRecordsByEntityNameAndExternalId({ entityName, connectionId, externalId, }: {
        entityName: string;
        connectionId: string;
        externalId: string;
    }): Promise<BaseRecord[]>;
}

export { type BaseEntity as B, type DatabaseConfig as D, FilterOperators as F, MastraEngine as M, PropertyType as P, type QueryOptions as Q, type SortOrder as S, type BaseRecord as a, type FilterCondition as b };
